// This is WXGLMAIN.H. Copyright (C) 2004 by Pawel Pilarczyk.
// It is the header file for YOUR program using wxWindows and Open GL.
// This is free software. No warranty. Consult 'license.txt' for details.
// Started on June 30, 2004. Last revision: August 13, 2004.


// Instructions:
// -------------
// If you want to write a simple, small program that displays an Open GL
// graphics which can be rotated and moved forward/backward interactively,
// you may find the code in "wxglmain.cpp" very useful.
// The only thing you have to implement yourself are the functions 
// and variables declared below.
// Of course, you should #include this file and link your program
// with "wxglmain.cpp", as well as the wxWindows library.


#ifndef _WXGLMAIN_H_
#define _WXGLMAIN_H_

// Include the appropriate OpenGL headers.
#ifdef __WXMAC__
# ifdef __DARWIN__
#   include <OpenGL/gl.h>
#   include <OpenGL/glu.h>
# else
#   include <gl.h>
#   include <glu.h>
# endif
#else
# include <GL/gl.h>
# include <GL/glu.h>
#endif


// --------------------------------------------------
// ---------------- already defined -----------------
// --------------------------------------------------
// The following variables are defined for you in this
// module, and you are supposed to use them and display
// your OpenGL graphics accordingly.

// The 4x4 matrix of the rotation of the scene
// that comes from the interactive user input.
extern float rotation [16];

// The translation vector of the scene (XYZ),
// to be applied after the rotation.
extern float translation [3];

// The background color of the scene (RGBA), defaults to black.
extern float bgcolor [4];

// The magnification exponent (0 = default size; can be negative).
extern double magnification;

// Should the picture be displayed as a wireframe?
extern bool wireframe;

// Should the fog effect be used?
extern bool fog;

// Should the perspective projection be used?
extern bool perspective;


// --------------------------------------------------
// --------------- need to be defined ---------------
// --------------------------------------------------
// The following variables and functions MUST be
// defined in your program.
// They are used by the interactive module.

// This text is displayed as help information in the program (unless empty).
extern const char *helpinfo;

// This function is called at initialization (resizePicture is called later).
void initPicture (int argc, char *argv []);

// This function is called on every canvas resize or when the magnification
// exponent, the translation vector or the projection mode have changed.
void resizePicture (int width, int height);

// This function is called at every paint event to draw the actual picture.
// This function should take into account the rotation matrix and various
// parameters of the picture (see above).
void drawPicture (void);

// This function is called upon program termination in order to allow you
// to free the resources you were using.
void deletePicture (void);

#endif // _WXGLMAIN_H_
